@@ -8,20 +8,34 @@ from llmling.cli.config import config_cli
 from llmling.cli.prompts import prompts_cli
 from llmling.cli.resources import resources_cli
 from llmling.cli.tools import tools_cli
+from llmling.config.store import ConfigStore
 
 
-HELP = """
+BASE_HELP = """
 🤖 LLMling CLI interface. Interact with resources, tools, and prompts! 🤖
 
+{config_info}
+
 Check out https://github.com/phil65/llmling !
 """
 
+
+def get_help_text() -> str:
+    """Get help text with active config information."""
+    try:
+        if active := ConfigStore().get_active():
+            return BASE_HELP.format(config_info=f"Active config: {active}")
+    except Exception:  # noqa: BLE001
+        pass
+    return BASE_HELP.format(config_info="No active config set")
+
+
 MISSING_SERVER = """
 Server commands require the mcp-server-llmling package.
 Install with: pip install mcp-server-llmling
 """
 
-cli = t.Typer(name="LLMling", help=HELP, no_args_is_help=True)
+cli = t.Typer(name="LLMling", help=get_help_text(), no_args_is_help=True)
 cli.add_typer(config_cli, name="config")
 cli.add_typer(resources_cli, name="resource")
 cli.add_typer(tools_cli, name="tool")
