@@ -12,9 +12,11 @@ from llmling.core import exceptions
 from llmling.core.log import get_logger
 from llmling.core.typedefs import MessageContent
 from llmling.resources.base import ResourceLoader, create_loaded_resource
+from llmling.utils.paths import guess_mime_type
 
 
 if TYPE_CHECKING:
+    from collections.abc import AsyncIterator
     import os
 
     from llmling.processors.registry import ProcessorRegistry
@@ -35,11 +37,10 @@ class ImageResourceLoader(ResourceLoader[ImageResource]):
         """Image URIs follow the same pattern as file URIs."""
         return "image:///{name}"
 
-    @classmethod
-    def create_uri(cls, *, name: str) -> str:
+    def create_uri(self, *, name: str, params: dict[str, str] | None = None) -> str:
         """Handle image paths properly."""
         normalized = name.replace("\\", "/").lstrip("/")
-        return cls.get_uri_template().format(name=normalized)
+        return self.get_uri_template().format(name=normalized)
 
     @classmethod
     def get_name_from_uri(cls, uri: str) -> str:
@@ -64,7 +65,7 @@ class ImageResourceLoader(ResourceLoader[ImageResource]):
         resource: ImageResource,
         name: str,
         processor_registry: ProcessorRegistry | None,
-    ) -> LoadedResource:
+    ) -> AsyncIterator[LoadedResource]:
         """Load and process image content."""
         try:
             path_obj = upath.UPath(resource.path)
@@ -87,41 +88,30 @@ class ImageResourceLoader(ResourceLoader[ImageResource]):
             placeholder_text = f"Image: {resource.path}"
             if resource.alt_text:
                 placeholder_text = f"{placeholder_text} - {resource.alt_text}"
-
-            return create_loaded_resource(
+            message_content = MessageContent(
+                type=content_type,
+                content=image_content,
+                alt_text=resource.alt_text,
+            )
+            metadata = {
+                "path": str(resource.path),
+                "type": "url" if is_url else "local",
+                "alt_text": resource.alt_text,
+            }
+            yield create_loaded_resource(
                 content=placeholder_text,
                 source_type="image",
                 uri=self.create_uri(name=name),
-                mime_type=self._detect_mime_type(path_obj),
+                mime_type=guess_mime_type(path_obj),
                 name=path_obj.name,
                 description=resource.alt_text,
-                additional_metadata={
-                    "path": str(resource.path),
-                    "type": "url" if is_url else "local",
-                    "alt_text": resource.alt_text,
-                },
-                content_items=[
-                    MessageContent(
-                        type=content_type,
-                        content=image_content,
-                        alt_text=resource.alt_text,
-                    )
-                ],
+                additional_metadata=metadata,
+                content_items=[message_content],
             )
         except Exception as exc:
             msg = f"Failed to load image from {resource.path}"
             raise exceptions.LoaderError(msg) from exc
 
-    def _detect_mime_type(self, path: str | os.PathLike[str]) -> str:
-        """Detect MIME type from file extension."""
-        ext = upath.UPath(path).suffix.lower()
-        return {
-            ".jpg": "image/jpeg",
-            ".jpeg": "image/jpeg",
-            ".png": "image/png",
-            ".gif": "image/gif",
-        }.get(ext, "application/octet-stream")
-
     async def _load_content(self, path_obj: str | os.PathLike[str], is_url: bool) -> str:
         """Load content from path.
 
