@@ -3,49 +3,24 @@
 from __future__ import annotations
 
 import asyncio
-import importlib
 from typing import TYPE_CHECKING, Any, TypeGuard
 
+from llmling.core.log import get_logger
+from llmling.utils.importing import import_callable
+
 
 if TYPE_CHECKING:
     from collections.abc import Awaitable, Callable
 
 
+logger = get_logger(__name__)
+
+
 def is_async_callable(obj: Any) -> TypeGuard[Callable[..., Awaitable[Any]]]:
     """Check if an object is an async callable."""
     return asyncio.iscoroutinefunction(obj)
 
 
-def import_callable(import_path: str) -> Callable[..., Any]:
-    """Import a callable from an import path.
-
-    Args:
-        import_path: Dot-separated path to callable (e.g., "module.submodule.func")
-
-    Returns:
-        The imported callable
-
-    Raises:
-        ValueError: If import fails or object is not callable
-    """
-    try:
-        module_path, callable_name = import_path.rsplit(".", 1)
-        module = importlib.import_module(module_path)
-        callable_obj = getattr(module, callable_name)
-
-        if not callable(callable_obj):
-            msg = f"Imported object {import_path} is not callable"
-            raise ValueError(msg)  # noqa: TRY004
-    except ImportError as exc:
-        msg = f"Could not import callable: {import_path}"
-        raise ValueError(msg) from exc
-    except AttributeError as exc:
-        msg = f"Could not find callable {import_path!r} "
-        raise ValueError(msg) from exc
-    else:
-        return callable_obj
-
-
 async def execute_callable(import_path: str, **kwargs: Any) -> Any:
     """Execute a callable and return its result.
 
@@ -61,7 +36,7 @@ async def execute_callable(import_path: str, **kwargs: Any) -> Any:
     """
     try:
         callable_obj = import_callable(import_path)
-
+        logger.debug("Executing %r: kwargs=%s", callable_obj, kwargs)
         # Execute the callable
         if is_async_callable(callable_obj):
             result = await callable_obj(**kwargs)
@@ -72,3 +47,7 @@ async def execute_callable(import_path: str, **kwargs: Any) -> Any:
         raise ValueError(msg) from exc
     else:
         return result
+
+
+if __name__ == "__main__":
+    import_callable("datetime.datetime.strftime")
